/* (C) 2022 YiRing, Inc. */
package com.yiring.app.rabbit.config;

import com.yiring.app.rabbit.receiver.PositionMessageHandler;
import javax.annotation.Resource;
import org.springframework.amqp.core.*;
import org.springframework.amqp.rabbit.connection.ConnectionFactory;
import org.springframework.amqp.rabbit.listener.SimpleMessageListenerContainer;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * 模拟真源 rabbitmq 消息队列配置
 *
 * @author ifzm
 * 2019/8/21 15:44
 */
@Configuration
@ConditionalOnProperty(prefix = "zy-config.rabbitmq", value = "mock", havingValue = "true")
public class MockZyRabbitConfig {

    @Resource
    ZyConfigProperties.ZyConfigRabbitmq rabbitmq;

    /**
     * 消息交换机
     */
    public static final String ZY_TOPIC_EXCHANGE = "zy.topic.exchange";

    /**
     * 订阅模式
     *
     * @return TopicExchange
     */
    @Bean(ZY_TOPIC_EXCHANGE)
    TopicExchange exchange() {
        return new TopicExchange(ZY_TOPIC_EXCHANGE, true, false);
    }

    @Bean
    Binding bindingExchangeMock(
        @Qualifier(ZyRabbitConfig.QUEUE_BEAN_NAME) Queue queue,
        @Qualifier(ZY_TOPIC_EXCHANGE) TopicExchange exchange
    ) {
        return BindingBuilder.bind(queue).to(exchange).with(rabbitmq.getQueueName());
    }

    @Bean(ZyRabbitConfig.LISTENER_CONTAINER_NAME)
    public SimpleMessageListenerContainer simpleMessageListenerContainer(
        PositionMessageHandler handler,
        @Qualifier(ZyRabbitConfig.QUEUE_BEAN_NAME) Queue queue,
        @Qualifier(RabbitConfig.CONNECTION_FACTORY_NAME) ConnectionFactory connectionFactory
    ) {
        return ZyRabbitConfig.buildPositionMessageListenerContainer(handler, queue, connectionFactory);
    }
}
