/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.risk.impl;

import cn.hutool.core.convert.Convert;
import com.yiring.app.domain.risk.RiskPush;
import com.yiring.app.domain.risk.RiskPushRepository;
import com.yiring.app.domain.risk.RiskWithdrawalPush;
import com.yiring.app.domain.risk.RiskWithdrawalPushRepository;
import com.yiring.app.param.risk.RiskWithdrawalPushSaveParam;
import com.yiring.app.service.risk.RiskWithdrawalPushService;
import com.yiring.app.vo.risk.RiskWithdrawalPushVo;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * 撤离推送
 *
 * @author LJ-2204
 * @date 2022/5/24
 */

@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class RiskWithdrawalPushServiceImpl implements RiskWithdrawalPushService {

    @Resource
    RiskWithdrawalPushRepository riskWithdrawalPushRepository;

    @Resource
    RiskPushRepository riskPushRepository;

    @Override
    public Result<String> add(RiskWithdrawalPushSaveParam param) {
        Optional<RiskPush> riskPushOptional = riskPushRepository.findById(param.getRiskPushId());
        if (riskPushOptional.isEmpty()) {
            return Result.no(Status.BAD_REQUEST, "风险规则不存在");
        }

        RiskWithdrawalPush riskWithdrawalPush = Convert.convert(RiskWithdrawalPush.class, param);
        riskWithdrawalPush.setRiskPush(riskPushOptional.get());
        riskWithdrawalPushRepository.save(riskWithdrawalPush);
        return Result.ok();
    }

    @Override
    public Result<PageVo<RiskWithdrawalPushVo>> page(PageParam pageParam) {
        Pageable pageable = PageRequest.of(pageParam.getPageNo() - 1, pageParam.getPageSize());
        Page<RiskWithdrawalPush> riskWithdrawalPushes = riskWithdrawalPushRepository.findAll(pageable);
        List<RiskWithdrawalPushVo> riskWithdrawalPushVos = riskWithdrawalPushes
            .stream()
            .map(riskWithdrawalPush -> Convert.convert(RiskWithdrawalPushVo.class, riskWithdrawalPush))
            .collect(Collectors.toList());
        PageVo<RiskWithdrawalPushVo> pageVo = PageVo.build(
            riskWithdrawalPushVos,
            riskWithdrawalPushes.getTotalElements()
        );
        return Result.ok(pageVo);
    }

    @Override
    public Result<String> delete(IdParam idParam) {
        Optional<RiskWithdrawalPush> riskWithdrawalPushOptional = riskWithdrawalPushRepository.findById(
            idParam.getId()
        );
        if (riskWithdrawalPushOptional.isEmpty()) {
            return Result.no(Status.BAD_REQUEST, "撤离推送数据不存在");
        }

        riskWithdrawalPushRepository.delete(riskWithdrawalPushOptional.get());
        return Result.ok();
    }

    @Override
    public Result<String> modify(RiskWithdrawalPushSaveParam param, IdParam idParam) {
        Optional<RiskWithdrawalPush> riskWithdrawalPushOptional = riskWithdrawalPushRepository.findById(
            idParam.getId()
        );
        if (riskWithdrawalPushOptional.isEmpty()) {
            return Result.no(Status.BAD_REQUEST, "撤离推送数据不存在");
        }

        RiskWithdrawalPush riskWithdrawalPush = riskWithdrawalPushOptional.get();

        Optional<RiskPush> riskPushOptional = riskPushRepository.findById(param.getRiskPushId());
        if (riskPushOptional.isEmpty()) {
            return Result.no(Status.BAD_REQUEST, "风险规则不存在");
        }

        riskWithdrawalPush.setRiskPush(riskPushOptional.get());
        riskWithdrawalPush.setScope(param.getScope());
        riskWithdrawalPush.setTypes(param.getTypes());
        riskWithdrawalPushRepository.save(riskWithdrawalPush);
        return Result.ok();
    }
}
