/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.workArea;

import com.yiring.app.param.workArea.WorkAreaParam;
import com.yiring.app.param.workArea.WorkAreaQueryParam;
import com.yiring.app.service.workArea.WorkAreaService;
import com.yiring.app.vo.workArea.WorkAreaVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/5/21 10:18
 */
@Slf4j
@Validated
@SuppressWarnings({ "deprecation" })
@Api(tags = "工区", description = "WorkArea")
@RestController
@RequestMapping("/workArea/")
public class WorkAreaController {

    @Resource
    WorkAreaService workAreaService;

    @ApiOperation(value = "新增工区信息")
    @PostMapping("saveWorkArea")
    public Result<String> saveWorkArea(@Valid WorkAreaParam workAreaParam) {
        return workAreaService.saveWorkArea(workAreaParam);
    }

    @ApiOperation(value = "修改工区信息")
    @PostMapping("updateWorkArea")
    public Result<String> updateWorkArea(@Valid WorkAreaParam workAreaParam, @Valid IdParam idParam) {
        return workAreaService.updateWorkArea(workAreaParam, idParam);
    }

    @ApiOperation(value = "删除工区信息")
    @PostMapping("deleteWorkArea")
    public Result<String> deleteWorkArea(@Valid IdParam idParam) {
        return workAreaService.deleteWorkArea(idParam);
    }

    @ApiOperation(value = "查看工区信息")
    @GetMapping("pageWorkArea")
    public Result<PageVo<WorkAreaVo>> pageWorkArea(@Valid WorkAreaQueryParam workAreaQueryParam) {
        return workAreaService.pageWorkArea(workAreaQueryParam);
    }

    @ApiOperation(value = "导出工区信息", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @PostMapping("export")
    public void export(HttpServletResponse response, @Valid WorkAreaQueryParam workAreaQueryParam) {
        workAreaService.export(workAreaQueryParam, response);
    }
}
